@@ -17,7 +17,16 @@ Some utility modules are also provided:
 
 from . import stream, pipe
 from .aiter_utils import async_, await_
-from .core import StreamEmpty, operator, streamcontext
+from .core import (
+    Stream,
+    StreamEmpty,
+    operator,
+    pipable_operator,
+    sources_operator,
+    streamcontext,
+)
+
+__version__ = "0.6.3"
 
 __all__ = [
     "stream",
@@ -25,6 +34,10 @@ __all__ = [
     "async_",
     "await_",
     "operator",
+    "pipable_operator",
+    "sources_operator",
     "streamcontext",
+    "Stream",
     "StreamEmpty",
+    "__version__",
 ]
